@@ -2,12 +2,14 @@
 nydus.db.backends.base
 ~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2011 DISQUS.
+:copyright: (c) 2011-2012 DISQUS.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
 __all__ = ('BaseConnection',)
 
+from nydus.db.base import BaseCluster
+
 
 class BasePipeline(object):
     """
@@ -17,17 +19,21 @@ class BasePipeline(object):
     API for dealing with pipelined commands.
     """
     def __init__(self, connection):
-        self.pending = []
         self.connection = connection
+        self.pending = []
 
     def add(self, command):
+        """
+        Add a command to the pending execution pipeline.
+        """
         self.pending.append(command)
 
     def execute(self):
-        results = {}
-        for command in self.pending:
-            results[command._ident] = command(*command._args, **command._kwargs)
-        return results
+        """
+        Execute all pending commands and return a list of the results
+        ordered by call.
+        """
+        raise NotImplementedError
 
 
 class BaseConnection(object):
@@ -45,6 +51,9 @@ class BaseConnection(object):
         self._connection = None
         self.num = num
 
+    def __getattr__(self, name):
+        return getattr(self.connection, name)
+
     @property
     def identifier(self):
         return repr(self)
@@ -56,21 +65,36 @@ class BaseConnection(object):
         return self._connection
 
     def close(self):
+        """
+        Close the connection if it is open.
+        """
         if self._connection:
             self.disconnect()
         self._connection = None
 
     def connect(self):
         """
-        connect() must return a connection object
+        Connect.
+
+        Must return a connection object.
         """
         raise NotImplementedError
 
     def disconnect(self):
+        """
+        Disconnect.
+        """
         raise NotImplementedError
 
     def get_pipeline(self):
-        return BasePipeline(self)
+        """
+        Return a new pipeline instance (bound to this connection).
+        """
+        raise NotImplementedError
 
-    def __getattr__(self, name):
-        return getattr(self.connection, name)
+    @classmethod
+    def get_cluster(cls):
+        """
+        Return the default cluster type for this backend.
+        """
+        return BaseCluster
